#rm(list=ls(all=TRUE))

#working directory as ab_pain_meta-analysis folder
source("R/load.R")
source("R/function.R")

#1 somatosensory modality ab chronic pain vs healthy

x<-metacont(n.e=n1i, mean.e=m1i,sd.e=sd1i,n.c=n2i, mean.c=m2i, sd.c=sd2i, 
            data=modality,comb.random=TRUE, comb.fixed=FALSE, sm="SMD", method.smd="Hedges")

png(file="graphics/modality_overall.png",width=750,height=350)
modality_forest <- forest(x, studlab=c("Peters et al. (2000)",
                    "De Tommaso et al. (2008) ",
                    "Snijders et al. (2010) ",
                    "Tiemann et al. (2012)",
                    "Van Damme et al. (2014)",
                    "Vandenbroucke et al. (2014)" ,
                    "Van Damme et al. (2015)", 
                    "Stankewitz et al. (2018)",
                    "Van Ryckeghem et al. (2018)",
                    "Moore et al. (2019)"),
       xlim=c(-1.5,1.7),
       lab.e="Chronic Pain", lab.c="Healthy",
       hetstat=TRUE, print.Q=TRUE,print.I2=TRUE, print.tau2=FALSE,rightlabs = c("SMD", "95% CI", "Weight"), hetlab="",
       digits.sd=2) 
dev.off()

inf <- metainf(x)
inf

#without Stankewitz because somatoform pain is different from other types of pain
modality2<-modality[-8,]
x<-metacont(n.e = n1i, mean.e = m1i,sd.e = sd1i,n.c = n2i, mean.c = m2i, sd.c = sd2i, 
            data = modality2,comb.random = TRUE, comb.fixed = FALSE, sm = "SMD", method.smd = "Hedges")

png(file="graphics/modality_overall_exc_outlier.png",width=750,height=350)
forest(x, studlab=c("Peters et al. (2000)",
                    "De Tommaso et al. (2008) ",
                    "Snijders et al. (2010) ",
                    "Tiemann et al. (2012)",
                    "Van Damme et al. (2014)",
                    "Vandenbroucke et al. (2014)" ,
                    "Van Damme et al. (2015)",
                    "Van Ryckeghem et al. (2018)",
                    "Moore et al. (2019)"), 
       xlim=c(-1.5,1.7),
       lab.e="Chronic Pain", lab.c="Healthy",
       hetstat=TRUE, print.Q=TRUE,print.I2=TRUE, print.tau2=FALSE,rightlabs = c("SMD", "95% CI", "Weight"), hetlab="",
       digits.sd=2)
dev.off()

#painful stimuli
x<-metacont(n.e=n1i, mean.e=m1i,sd.e=sd1i,n.c=n2i, mean.c=m2i, sd.c=sd2i, 
            data=modality_painful,comb.random=TRUE, comb.fixed=FALSE, sm="SMD", method.smd="Hedges")

png(file="graphics/modality_painful_stimuli.png",width=750,height=350)
forest(x, studlab=c("De Tommaso et al. (2008) ",
                    "Snijders et al. (2010) ",
                    "Tiemann et al. (2012)",
                    "Stankewitz et al. (2018)",
                    "Van Ryckeghem et al. (2018)",
                    "Moore et al. (2019)"), 
       xlim=c(-1.5,1.7),
       lab.e="Chronic Pain", lab.c="Healthy",
       hetstat=TRUE, print.Q=TRUE,print.I2=TRUE, print.tau2=FALSE,rightlabs = c("SMD", "95% CI", "Weight"), hetlab="",
       digits.sd=2)
dev.off()


#painful stimuli omitting Stankewitz
modality_painful_exc_outlier <- modality_painful[-4,]
x<-metacont(n.e=n1i, mean.e=m1i,sd.e=sd1i,n.c=n2i, mean.c=m2i, sd.c=sd2i, 
            data=modality_painful_exc_outlier,comb.random=TRUE, comb.fixed=FALSE, sm="SMD", method.smd="Hedges")

png(file="graphics/modality_painful_stimuli_exc_outlier.png",width=750,height=350)
forest(x, studlab=c("De Tommaso et al. (2008) ",
                    "Snijders et al. (2010) ",
                    "Tiemann et al. (2012)",
                    "Van Ryckeghem et al. (2018)",
                    "Moore et al. (2019)"), 
       xlim=c(-1.5,1.7),
       lab.e="Chronic Pain", lab.c="Healthy",
       hetstat=TRUE, print.Q=TRUE,print.I2=TRUE, print.tau2=FALSE,rightlabs = c("SMD", "95% CI", "Weight"), hetlab="",
       digits.sd=2)
dev.off()

#non-painful stimuli
x<-metacont(n.e=n1i, mean.e=m1i,sd.e=sd1i,n.c=n2i, mean.c=m2i, sd.c=sd2i, 
            data=modality_non_painful,comb.random=TRUE, comb.fixed=FALSE, sm="SMD", method.smd="Hedges")

png(file="graphics/modality_non_painful_stimuli.png",width=750,height=350)
forest(x, studlab=c("Peters et al. (2000)",
                    "Snijders et al. (2010) ",
                    "Van Damme et al. (2014)",
                    "Vandenbroucke et al. (2014)" ,
                    "Van Damme et al. (2015)"), 
       xlim=c(-1.5,1.5),
       lab.e="Chronic Pain", lab.c="Healthy",
       hetstat=TRUE, print.Q=TRUE,print.I2=TRUE, print.tau2=FALSE,rightlabs = c("SMD", "95% CI", "Weight"), hetlab="",
       digits.sd=2)
dev.off()

#fibromyalgia subgroup
x<-metacont(n.e=n1i, mean.e=m1i,sd.e=sd1i,n.c=n2i, mean.c=m2i, sd.c=sd2i, 
            data=modality[modality$condition=="fibromyalgia",],comb.random=TRUE, comb.fixed=FALSE, sm="SMD", method.smd="Hedges")

png(file="graphics/modality_fibromyalgia.png",width=750,height=350)
forest(x, studlab=c("Peters et al. (2000)",
                    "Tiemann et al. (2012)",
                    "Vandenbroucke et al. (2014)" ,
                    "Van Damme et al. (2015)",
                    "Van Ryckeghem et al. (2018)",
                    "Moore et al. (2019)"), 
       xlim=c(-1.5,1.5),
       lab.e="Chronic Pain", lab.c="Healthy",
       hetstat=TRUE, print.Q=TRUE,print.I2=TRUE, print.tau2=FALSE,rightlabs = c("SMD", "95% CI", "Weight"), hetlab="",
       digits.sd=2)
dev.off()

#common task subgroup
x<-metacont(n.e=n1i, mean.e=m1i,sd.e=sd1i,n.c=n2i, mean.c=m2i, sd.c=sd2i, 
            data=modality_common_task,comb.random=TRUE, comb.fixed=FALSE, sm="SMD", method.smd="Hedges")

png(file="graphics/modality_common_task.png",width=750,height=350)
forest(x, studlab=c("De Tommaso et al. (2008) ",
                    "Snijders et al. (2010) ",
                    "Stankewitz et al. (2018)",
                    "Van Ryckeghem et al. (2018)"), 
       xlim=c(-1.5,1.7),
       lab.e="Chronic Pain", lab.c="Healthy",
       hetstat=TRUE, print.Q=TRUE,print.I2=TRUE, print.tau2=FALSE,rightlabs = c("SMD", "95% CI", "Weight"), hetlab="",
       digits.sd=2)
dev.off()

#common task subgroup omitting Stakewitz et al. (2018)
modality_common_task_exc_outlier<-modality_common_task[-3,]
x<-metacont(n.e=n1i, mean.e=m1i,sd.e=sd1i,n.c=n2i, mean.c=m2i, sd.c=sd2i, 
            data=modality_common_task_exc_outlier,comb.random=TRUE, comb.fixed=FALSE, sm="SMD", method.smd="Hedges")

png(file="graphics/modality_common_task_exc_outlier.png", width=750, height=350)
forest(x, studlab=c("De Tommaso et al. (2008) ",
                    "Snijders et al. (2010) ",
                    "Van Ryckeghem et al. (2018)"), 
       xlim=c(-1.5,1.7),
       lab.e="Chronic Pain", lab.c="Healthy",
       hetstat=TRUE, print.Q=TRUE,print.I2=TRUE, print.tau2=FALSE,rightlabs = c("SMD", "95% CI", "Weight"), hetlab="",
       digits.sd=2)
dev.off()

#primary task subgroup
x<-metacont(n.e=n1i, mean.e=m1i,sd.e=sd1i,n.c=n2i, mean.c=m2i, sd.c=sd2i, 
            data=modality_primary_task,comb.random=TRUE, comb.fixed=FALSE, sm="SMD", method.smd="Hedges")

png(file="graphics/modality_primary_task.png",width=750,height=350)
forest(x, studlab=c("Tiemann et al. (2012)",
                    "Van Ryckeghem et al. (2018)",
                    "Moore et al. (2019)"), 
       xlim=c(-1.5,1.5),
       lab.e="Chronic Pain", lab.c="Healthy",
       hetstat=TRUE, print.Q=TRUE,print.I2=TRUE, print.tau2=FALSE,rightlabs = c("SMD", "95% CI", "Weight"), hetlab="",
       digits.sd=2)
dev.off()



#############################################################################################################
#2 spatial attentional bias affected vs unaffected sides
x<-metamean(n=n1i, mean=m1i, sd=sd1i, data=spatial_within, 
            comb.random = TRUE, comb.fixed=FALSE, null.effect=0, sm="MRAW")


png(file="graphics/spatial_within_subject.png",width=750,height=350)
forest(x, studlab=c("Moseley et al. (2009)          ", 
                    "Moseley et al. (2012a) Exp. 1",
                    "Moseley et al. (2012b) Exp. 1a",
                    "Moseley et al. (2012b) Exp. 2a",
                    "Moseley et al. (2012b) Exp. 3a", 
                    "Reid et al. (2016) ",
                    "Van Damme et al. (2018)"),
       xlim=c(-50,55),
       xlab="Mean PSS (ms)", smlab="Ipsilateral     Contralateral",
       print.Q=TRUE, print.I2=TRUE, print.tau2=FALSE,rightlabs = c("Mean", "95% CI", "Weight"), hetlab="",
       digits.sd = 2)
dev.off()

inf <- metainf(x)
inf


#omitting Van Damme et al. (2018) 
x<-metamean(n=n1i, mean=m1i, sd=sd1i, data=spatial_within[1:6,], 
            comb.random = TRUE, comb.fixed=FALSE, null.effect=0, sm="MRAW")
png(file="graphics/spatial_within_subject_exc_outlier.png",width=750,height=350)
forest(x, studlab=c("Moseley et al. (2009)          ", 
                    "Moseley et al. (2012a) Exp. 1",
                    "Moseley et al. (2012b) Exp. 1a",
                    "Moseley et al. (2012b) Exp. 2a",
                    "Moseley et al. (2012b) Exp. 3a", 
                    "Reid et al. (2016) "),
       xlim=c(-50,55),
       xlab="Mean PSS (ms)", smlab="Ipsilateral     Contralateral",
       print.Q=TRUE, print.I2=TRUE, print.tau2=FALSE,rightlabs = c("Mean", "95% CI", "Weight"), hetlab="")
dev.off()


#CRPS subgroup
x<-metamean(n=n1i, mean=m1i, sd=sd1i, data=spatial_within[spatial_within$condition == "CRPS",], 
            comb.random = TRUE, comb.fixed=FALSE, null.effect=0, sm="MRAW")
png(file="graphics/spatial_within_subject_crps.png",width=750,height=350)
forest(x, studlab=c("Moseley et al. (2009)          ", 
                    "Moseley et al. (2012a) Exp. 1",
                    "Reid et al. (2016) "),
       xlim=c(-50,55),
       xlab="Mean PSS (ms)", smlab="Ipsilateral     Contralateral",
       print.Q=TRUE, print.I2=TRUE, print.tau2=FALSE,rightlabs = c("Mean", "95% CI", "Weight"), hetlab="")
dev.off()


#back pain subgroup
x<-metamean(n=n1i, mean=m1i, sd=sd1i, data=spatial_within[spatial_within$condition == "lower back pain",], 
            comb.random = TRUE, comb.fixed=FALSE, null.effect=0, sm="MRAW")
png(file="graphics/spatial_within_subject_back_pain.png",width=750,height=350)
forest(x, studlab=c("Moseley et al. (2012b) Exp. 1a",
                    "Moseley et al. (2012b) Exp. 2a",
                    "Moseley et al. (2012b) Exp. 3a"),
       xlim=c(-50,55),
       xlab="Mean PSS (ms)", smlab="Ipsilateral     Contralateral",
       print.Q=TRUE, print.I2=TRUE, print.tau2=FALSE,rightlabs = c("Mean", "95% CI", "Weight"), hetlab="")
dev.off()

##########################################################################################

#3 spatial chronic pain vs healthy
x<-metacont(n.e=n1i, mean.e=m1i,sd.e=sd1i,n.c=n2i, mean.c=m2i, sd.c=sd2i, 
            data=spatial_between,comb.random=TRUE, comb.fixed=FALSE, sm="SMD", method.smd="Hedges")
png(file="graphics/spatial_between_subject.png",width=750,height=350)
forest(x, studlab=c("Moseley et al. (2012a) Exp. 1", 
                    "Moseley et al. (2012b) Exp. 1a",
                    "Van Damme et al. (2018)"),
       xlim=c(-3,3),
       lab.e="Chronic Pain", lab.c="Healthy", smlab="Ipsilateral     Contralateral",
       hetstat=TRUE, print.Q=TRUE,print.I2=TRUE, print.tau2=FALSE,rightlabs = c("SMD", "95% CI", "Weight"),hetlab="")
dev.off()
inf <- metainf(x)
inf


#omitting Van Damme et al. (2018) 
x<-metacont(n.e=n1i, mean.e=m1i,sd.e=sd1i,n.c=n2i, mean.c=m2i, sd.c=sd2i, 
            data=spatial_between[1:2,],comb.random=TRUE, comb.fixed=FALSE, sm="SMD", method.smd="Hedges")
png(file="graphics/spatial_between_subject_exc_outlier.png",width=750,height=350)
forest(x, studlab=c("Moseley et al. (2012a) Exp. 1", 
                    "Moseley et al. (2012b) Exp. 1a"),
       xlim=c(-3,3),
       lab.e="Chronic Pain", lab.c="Healthy", smlab="Ipsilateral     Contralateral",
       hetstat=TRUE, print.Q=TRUE,print.I2=TRUE, print.tau2=FALSE,rightlabs = c("SMD", "95% CI", "Weight"), hetlab="")
dev.off()
#####################################################################################################################
#4 visual stimuli pain affected vs pain unaffected sides

x<-metamean(n=n1i, mean=m1i, sd=sd1i, data=visual_within, 
            comb.random = TRUE, comb.fixed=FALSE, null.effect=0, sm="MRAW")

png(file="graphics/visual_within_subjects.png",width=750,height=350)
forest(x, studlab=c("Bultitude et al. (2017)                 ", 
                    "Filbrich et al. (2017)"),
       xlim=c(-30,40),
       xlab="Mean PSS (ms)", smlab="Ipsilateral     Contralateral",
       hetstat=TRUE, print.Q=TRUE,print.I2=TRUE, print.tau2=FALSE,rightlabs = c("Mean", "95% CI", "Weight"), hetlab="")
dev.off()
#######################################################################################################################

#risk of bias
plot<-rob.summary(data=rob)
new.plot<-plot+ scale_x_discrete(labels=c("replicable_sampling_method" = "Replicable sampling method", 
                                          "recognised_diagnosis_criteria" = "Recognised diagnosis inclusion criteria",
                                          "matched_controls" = "Matched controls",
                                          "researcher_blinded" = "Researcher blinded to group",
                                          "replicable_method" = "Replicable method",
                                          "paradigm_validated" = "Paradigm validated",
                                          "power_calc" = "A priori power calculation",
                                          "missing_data_dealt_with" = "Missing data",
                                          "all_outcomes_reported" = "Selective outcome reporting"))+
  labs(x="Percentage of included studies")

png(file="graphics/risk_of_bias.png",width=750,height=500)
new.plot
dev.off()

#cohen's kappa
just_ratings <- rob_ratings %>%
  select(PB, DS)
cohen.kappa(just_ratings)

rob_ratings2 <- rob_ratings %>%
  mutate(agree = PB == DS)
table(rob_ratings2$agree)
100 - ((21/(232+21))*100)

#####################################################################################################
#publication bias for modality between-group studies
x<-metacont(n.e=n1i, mean.e=m1i,sd.e=sd1i,n.c=n2i, mean.c=m2i, sd.c=sd2i, 
            data=pub_bias_between_modality,comb.random=TRUE, comb.fixed=FALSE, sm="SMD", method.smd="Hedges")

png(file="graphics/pub_bias_modality.png",width=750,height=500)
modality_funnel <- funnel(x, main = "Between-Group Modality AB", cex.lab = 1.2, cex.main = 1.2, cex.axis = 1.2)
dev.off()

png(file="graphics/pub_bias_modality_contour.png",width=750,height=500)
modality_funnel2 <- funnel(x, ref.triangle = TRUE, lty.random = 0,contour.levels = c(0.90, 0.95, 0.99), col.contour = c("cadetblue4", "cadetblue3", "gray87"),
       family="D", main = "Between-Group Modality AB", cex.lab = 1.2, cex.main = 1.2, cex.axis = 1.2)
dev.off()

metabias(x, model="rma", predictor="sei", k.min = 2)

#publication bias for spatial between-group studies
y<-metacont(n.e=n1i, mean.e=m1i,sd.e=sd1i,n.c=n2i, mean.c=m2i, sd.c=sd2i, 
            data=pub_bias_between_spatial,comb.random=TRUE, comb.fixed=FALSE, sm="SMD", method.smd="Hedges")

png(file="graphics/pub_bias_spatial_between.png",width=750,height=500)
spatial_between_funnel <- funnel(y,comb.random = TRUE, family="D", main = "Between-Group Spatial AB", cex.lab = 1.2, cex.main = 1.2, cex.axis = 1.2)
dev.off()

png(file="graphics/pub_bias_spatial_between_contour.png",width=750,height=500)
spatial_between_funnel2 <- funnel(y, ref.triangle = TRUE, lty.random = 0,contour.levels = c(0.90, 0.95, 0.99), col.contour = c("cadetblue4", "cadetblue3", "gray87"),
       family="D", main = "Between-Group Spatial AB", cex.lab = 1.2, cex.main = 1.2, cex.axis = 1.2)
dev.off()

metabias(y, model="rma", predictor="sei", k.min = 2)

#publication bias for within group studies
z<-metamean(n=n1i, mean=m1i, sd=sd1i, data=pub_bias_within_spatial, 
            comb.random = TRUE, comb.fixed=FALSE, null.effect=0, sm="MRAW")

png(file="graphics/pub_bias_spatial_within.png",width=750,height=500)
spatial_within_funnel <- funnel(z,comb.random = TRUE, family="D", main = "Within-Group Spatial AB", cex.lab = 1.2, cex.main = 1.2, cex.axis = 1.2)
dev.off()

png(file="graphics/pub_bias_spatial_within_contour.png",width=750,height=500)
spatial_within_funnel2 <- funnel(z, ref.triangle = TRUE, lty.random = 0,contour.levels = c(0.90, 0.95, 0.99), col.contour = c("cadetblue4", "cadetblue3", "gray87"),
       family="D", main = "Within-Group Spatial AB", cex.lab = 1.2, cex.main = 1.2, cex.axis = 1.2)
dev.off()

metabias(z, model="rma", predictor="sei", k.min = 2)